==> haskell-invariant-0.6.4-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-72QoKt8iHvgLvK6oZ7TU8m
key:                  invariant-0.6.4-72QoKt8iHvgLvK6oZ7TU8m
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  0a6ad7addc5f6b0c283e38e1bd1f5254
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-72QoKt8iHvgLvK6oZ7TU8m
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6.2-LX2r8mypqWoEMCvwdCtLUH
    comonad-5.0.9-Er3eq4gTywwJing4fQLPZd containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.3-Awvi78GiKWR1SSMXJ32bHl stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-3iRUctzIz2JCUYhLp7SKku

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.4-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-CI2wjR0yn75AcCtkDVVjG
key:                  invariant-0.6.4-CI2wjR0yn75AcCtkDVVjG
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  5e59d5543249b8157badf3434187f1c5
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-CI2wjR0yn75AcCtkDVVjG
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6.2-8SKDXId5RXfJn3kOqYrjFY
    comonad-5.0.9-WdRIGdTjRI2TeSrvZ2o2 containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.3-KQSjYECC9ooGQWXQlWDirn stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-3czZ5Len2GTFaAkRxFZe7E

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
